@@ -25,9 +25,11 @@ from .core import (angular as _angular,
                    translation as _translation,
                    vector as _vector)
 from .core.hints import (QuaternaryPointFunction as _QuaternaryPointFunction,
-                         SquareRooter as _SquareRooter)
+                         SquareRooter as _SquareRooter,
+                         TernaryPointFunction as _TernaryPointFunction)
 
 _QuaternaryFunction = _QuaternaryPointFunction[_hints.Scalar]
+_TernaryFunction = _TernaryPointFunction[_hints.Scalar]
 
 Location = _enums.Location
 Kind = _enums.Kind
@@ -48,9 +50,10 @@ class Context:
     __slots__ = ('_angular', '_box_cls', '_centroidal', '_circular',
                  '_contour_cls', '_empty', '_empty_cls', '_measured',
                  '_metric', '_mix_cls', '_mode', '_multipoint_cls',
-                 '_multipolygon_cls', '_multisegment_cls', '_point_cls',
-                 '_polygon_cls', '_rotation', '_scaling', '_segment',
-                 '_segment_cls', '_sqrt', '_translation', '_vector')
+                 '_multipolygon_cls', '_multisegment_cls', '_origin',
+                 '_point_cls', '_polygon_cls', '_rotation', '_scaling',
+                 '_segment', '_segment_cls', '_sqrt', '_translation',
+                 '_vector')
 
     def __init__(self,
                  *,
@@ -76,6 +79,7 @@ class Context:
         self._multipoint_cls = multipoint_cls
         self._multipolygon_cls = multipolygon_cls
         self._multisegment_cls = multisegment_cls
+        self._origin = point_cls(0, 0)
         self._point_cls = point_cls
         self._polygon_cls = polygon_cls
         self._segment_cls = segment_cls
@@ -107,7 +111,7 @@ class Context:
                               skip_defaults=True)
 
     @property
-    def angle_kind(self) -> _QuaternaryPointFunction[Kind]:
+    def angle_kind(self) -> _TernaryPointFunction[Kind]:
         """
         Returns function for computing angle kind.
 
@@ -131,7 +135,7 @@ class Context:
         return self._angular.kind
 
     @property
-    def angle_orientation(self) -> _QuaternaryPointFunction[Orientation]:
+    def angle_orientation(self) -> _TernaryPointFunction[Orientation]:
         """
         Returns function for computing angle orientation.
 
@@ -271,6 +275,11 @@ class Context:
         """Returns type for multisegments."""
         return self._multisegment_cls
 
+    @property
+    def origin(self) -> _hints.Point:
+        """Returns origin."""
+        return self._origin
+
     @property
     def point_cls(self) -> _Type[_hints.Point]:
         """Returns type for points."""
@@ -1020,7 +1029,8 @@ class Context:
     def rotate_multipolygon_around_origin(self,
                                           multipolygon: _hints.Multipolygon,
                                           cosine: _hints.Scalar,
-                                          sine: _hints.Scalar) -> _hints.Multipolygon:
+                                          sine: _hints.Scalar
+                                          ) -> _hints.Multipolygon:
         """
         Returns multipolygon rotated by given angle around origin.
 
@@ -1280,7 +1290,7 @@ class Context:
     def rotate_segment_around_origin(self,
                                      segment: _hints.Segment,
                                      cosine: _hints.Scalar,
-                                     sine: _hints.Scalar) -> _hints.Point:
+                                     sine: _hints.Scalar) -> _hints.Segment:
         """
         Returns segment rotated by given angle around origin.
 
