@@ -1,7 +1,8 @@
-from fractions import Fraction
 from typing import (Callable,
                     Type)
 
+from cfractions import Fraction
+
 from ground.core.hints import (Multipoint,
                                Point)
 
