@@ -1,17 +1,16 @@
 from typing import (Callable,
-                    Sequence,
                     Type)
 
-from ground.core.hints import (Coordinate,
+from ground.core.hints import (Multisegment,
                                Point,
-                               Segment)
+                               Scalar)
 
 
-def centroid(segments: Sequence[Segment],
+def centroid(multisegment: Multisegment,
              point_cls: Type[Point],
-             sqrt: Callable[[Coordinate], Coordinate]) -> Point:
+             sqrt: Callable[[Scalar], Scalar]) -> Point:
     accumulated_x = accumulated_y = accumulated_length = 0
-    for segment in segments:
+    for segment in multisegment.segments:
         start, end = segment.start, segment.end
         length = sqrt((end.x - start.x) ** 2 + (end.y - start.y) ** 2)
         accumulated_x += (start.x + end.x) * length
