@@ -7,5 +7,7 @@ from ground.core.hints import (Point,
 
 
 def centroid(segment: Segment, point_cls: Type[Point]) -> Point:
-    return point_cls(Expansion(segment.start.x, segment.end.x) / 2,
-                     Expansion(segment.start.y, segment.end.y) / 2)
+    return point_cls((Expansion(segment.start.x)
+                      + Expansion(segment.end.x)) / 2,
+                     (Expansion(segment.start.y)
+                      + Expansion(segment.end.y)) / 2)
