@@ -43,10 +43,6 @@ class Point(Protocol[Scalar]):
     def y(self) -> Scalar:
         """Ordinate of the point."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Point') -> bool:
-        """Checks if the point is equal to the other."""
-
     @abstractmethod
     def __ge__(self, other: 'Point') -> bool:
         """Checks if the point is greater than or equal to the other."""
@@ -109,10 +105,6 @@ class Box(Protocol[Scalar]):
     def min_y(self) -> Scalar:
         """Minimum ``y``-coordinate of the box."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Box') -> bool:
-        """Checks if the box is equal to the other."""
-
 
 @runtime_checkable
 class Empty(Protocol):
@@ -123,10 +115,6 @@ class Empty(Protocol):
     def __new__(cls) -> 'Empty':
         """Constructs empty geometry."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Empty') -> bool:
-        """Checks if the empty geometry is equal to the other."""
-
 
 _T = TypeVar('_T')
 Maybe = Union[Empty, _T]
@@ -149,10 +137,6 @@ class Multipoint(Protocol[Scalar]):
     def points(self) -> Sequence[Point]:
         """Points of the multipoint."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Multipoint') -> bool:
-        """Checks if the multipoint is equal to the other."""
-
 
 @runtime_checkable
 class Segment(Protocol[Scalar]):
@@ -177,10 +161,6 @@ class Segment(Protocol[Scalar]):
     def end(self) -> Point:
         """End endpoint of the segment."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Segment') -> bool:
-        """Checks if the segment is equal to the other."""
-
 
 @runtime_checkable
 class Multisegment(Protocol[Scalar]):
@@ -199,10 +179,6 @@ class Multisegment(Protocol[Scalar]):
     def segments(self) -> Sequence[Segment]:
         """Segments of the multisegment."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Multisegment') -> bool:
-        """Checks if the multisegment is equal to the other."""
-
 
 @runtime_checkable
 class Contour(Protocol[Scalar]):
@@ -221,10 +197,6 @@ class Contour(Protocol[Scalar]):
     def vertices(self) -> Sequence[Point]:
         """Vertices of the contour."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Contour') -> bool:
-        """Checks if the contour is equal to the other."""
-
 
 @runtime_checkable
 class Polygon(Protocol[Scalar]):
@@ -249,10 +221,6 @@ class Polygon(Protocol[Scalar]):
     def holes(self) -> Sequence[Contour]:
         """Holes of the polygon."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Polygon') -> bool:
-        """Checks if the polygon is equal to the other."""
-
 
 @runtime_checkable
 class Multipolygon(Protocol[Scalar]):
@@ -271,10 +239,6 @@ class Multipolygon(Protocol[Scalar]):
     def polygons(self) -> Sequence[Polygon]:
         """Polygons of the multipolygon."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Multipolygon') -> bool:
-        """Checks if the multipolygon is equal to the other."""
-
 
 Linear = Union[Segment, Multisegment, Contour]
 Shaped = Union[Polygon, Multipolygon]
@@ -295,10 +259,6 @@ class Mix(Protocol[Scalar]):
                 shaped: Maybe[Shaped]) -> 'Mix':
         """Constructs mix given its components."""
 
-    @abstractmethod
-    def __eq__(self, other: 'Mix') -> bool:
-        """Checks if the mix is equal to the other."""
-
     @property
     @abstractmethod
     def discrete(self) -> Maybe[Multipoint]:
